# Welcome to nem-reader documentation!

The Australian Energy Market Operator (AEMO) defines a [Meter Data File Format(MDFF)][mdff]
for reading energy billing data. This library sets out to parse these
NEM12 (interval metering data) and NEM13 (accumulated metering data)
data files into a useful python object, for use in other projects.

[mdff]: https://www.aemo.com.au/Stakeholder-Consultation/Consultations/Meter-Data-File-Format-Specification-NEM12-and-NEM13